==> react-lds-8.7.0.tgz: package/es/components/Table/Row.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var Row = React.forwardRef(function (props, ref) {
  var children = props.children,
      className = props.className,
      sticky = props.sticky,
      variation = props.variation,
      style = props.style,
      rest = _objectWithoutProperties(props, ["children", "className", "sticky", "variation", "style"]);

  var rowStyle = sticky ? _objectSpread({}, Row.STICKY_SCROLLED_STYLE, {}, style) : style;
  var variationClasses = Array.isArray(variation) ? variation.map(function (f) {
    return "slds-".concat(f);
  }) : "slds-".concat(variation);
  return React.createElement("tr", _extends({}, rest, {
    className: cx([variationClasses, className]),
    ref: ref,
    style: rowStyle
  }), children);
});
Row.STICKY_SCROLLED_STYLE = {
  position: 'sticky',
  top: 0,
  zIndex: 1
};
Row.defaultProps = {
  children: null,
  className: null,
  sticky: false,
  style: {},
  variation: []
};
Row.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * row content
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * Should only be set for rows nested in thead. Sets `position:sticky` to attach to top of the scrolling ctx
   */
  sticky: PropTypes.bool,
  style: PropTypes.object,

  /**
   * variation: string or array of strings. Variations: is-selected, hint-parent
   */
  variation: PropTypes.oneOfType([PropTypes.oneOf(['is-selected', 'hint-parent']), PropTypes.arrayOf(PropTypes.oneOf(['is-selected', 'hint-parent']))])
} : {};
export default Row;

==> react-lds-9.1.0.tgz: package/es/components/Table/Row.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/web.dom-collections.for-each";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var Row = React.forwardRef(function (props, ref) {
  var children = props.children,
      className = props.className,
      sticky = props.sticky,
      variation = props.variation,
      style = props.style,
      rest = _objectWithoutProperties(props, ["children", "className", "sticky", "variation", "style"]);

  var rowStyle = sticky ? _objectSpread({}, Row.STICKY_SCROLLED_STYLE, {}, style) : style;
  var variationClasses = Array.isArray(variation) ? variation.map(function (f) {
    return "slds-".concat(f);
  }) : "slds-".concat(variation);
  return React.createElement("tr", _extends({}, rest, {
    className: cx([variationClasses, className]),
    ref: ref,
    style: rowStyle
  }), children);
});
Row.STICKY_SCROLLED_STYLE = {
  position: 'sticky',
  top: 0,
  zIndex: 1
};
Row.defaultProps = {
  children: null,
  className: null,
  sticky: false,
  style: {},
  variation: []
};
Row.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * row content
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * Should only be set for rows nested in thead. Sets `position:sticky` to attach to top of the scrolling ctx
   */
  sticky: PropTypes.bool,
  style: PropTypes.object,

  /**
   * variation: string or array of strings. Variations: is-selected, hint-parent
   */
  variation: PropTypes.oneOfType([PropTypes.oneOf(['is-selected', 'hint-parent']), PropTypes.arrayOf(PropTypes.oneOf(['is-selected', 'hint-parent']))])
} : {};
export default Row;
